Learn R Programming

googlePublicData (version 0.15.7.28)

gender_country_slice: Some Countries statistics at Gender level

Description

This data set is one used in the DSPL Tutorial. Specifically, it contains the population magnitudes at country and gender level since 1960 to 1961.

Usage

data(gender_country_slice)

Arguments

Format

A data frame containing 13 observations.