Rdocumentation
powered by
Learn R Programming
googlePublicData (version 0.15.7.28)
country_slice: Some countries statistics
Description
This data set is one used in the DSPL Tutorial. Specifically, it contains the population magnitudes at country level since 1960 to 1963.
Usage
data(country_slice)
Arguments
Format
A data frame containing 13 observations.
DSPL Google Code Page Downloads:
https://code.google.com/p/dspl/downloads/detail?name=tutorial1.0.zip&can=2&q=